@@ -16,8 +16,7 @@ from lollypop.view_flowbox import FlowBoxView
 from lollypop.define import App, Type, ViewType, OrderBy, ScanUpdate
 from lollypop.widgets_artist_rounded import RoundedArtistWidget
 from lollypop.objects_album import Album
-from lollypop.utils import get_icon_name, get_font_height
-from lollypop.utils import get_default_storage_type
+from lollypop.utils import get_icon_name
 from lollypop.helper_signals import SignalsHelper, signals_map
 
 
@@ -39,7 +38,7 @@ class RoundedArtistsView(FlowBoxView, SignalsHelper):
         return [
             (App().art, "artist-artwork-changed",
              "_on_artist_artwork_changed"),
-            (App().scanner, "artist-updated", "_on_artist_updated")
+            (App().scanner, "updated", "_on_collection_updated")
         ]
 
     def populate(self, artist_ids=[]):
@@ -71,15 +70,15 @@ class RoundedArtistsView(FlowBoxView, SignalsHelper):
 #######################
 # PROTECTED           #
 #######################
-    def _get_child(self, value):
+    def _get_child(self, item):
         """
             Get a child for view
-            @param value as object
+            @param item as (int, str, str)
             @return row as SelectionListRow
         """
         if self.destroyed:
             return None
-        widget = RoundedArtistWidget(value, self.view_type, self.font_height)
+        widget = RoundedArtistWidget(item, self.view_type, self.font_height)
         self._box.insert(widget, -1)
         widget.show()
         return widget
@@ -97,10 +96,9 @@ class RoundedArtistsView(FlowBoxView, SignalsHelper):
                           App().window.is_adaptive)
         menu_widget = MenuBuilder(menu, False)
         menu_widget.show()
-        menu_ext = SimilarsMenu()
+        menu_ext = SimilarsMenu(child.data)
         menu_ext.show()
-        menu_ext.populate(child.data)
-        menu_widget.append_widget(menu_ext)
+        menu_widget.add_widget(menu_ext)
         return menu_widget
 
     def _on_child_activated(self, flowbox, child):
@@ -122,7 +120,8 @@ class RoundedArtistsView(FlowBoxView, SignalsHelper):
         child = self._box.get_child_at_pos(x, y)
         if child is None or child.artwork is None:
             return
-        album_ids = App().albums.get_ids([child.data], [], self.storage_type)
+        album_ids = App().albums.get_ids([], [child.data],
+                                         self.storage_type, False)
         albums = [Album(album_id) for album_id in album_ids]
         if albums:
             App().player.play_album_for_albums(albums[0], albums)
@@ -137,33 +136,23 @@ class RoundedArtistsView(FlowBoxView, SignalsHelper):
             if child.name == prefix:
                 child.set_artwork()
 
-    def _on_artist_updated(self, scanner, artist_id, scan_update):
+    def _on_collection_updated(self, scanner, item, scan_update):
         """
             Add/remove artist to/from list
             @param scanner as CollectionScanner
-            @param artist_id as int
+            @param item as CollectionItem
             @param scan_update as ScanUpdate
         """
-        if scan_update == ScanUpdate.ADDED:
-            storage_type = get_default_storage_type()
-            artist_ids = App().artists.get_ids([], storage_type)
-            # Can happen during scan
-            if artist_id not in artist_ids:
-                return
-            position = artist_ids.index(artist_id)
-            artist_name = App().artists.get_name(artist_id)
-            sortname = App().artists.get_sortname(artist_id)
-            widget = RoundedArtistWidget((artist_id, artist_name, sortname),
-                                         self.view_type,
-                                         get_font_height())
-            self._box.insert(widget, position)
-            widget.show()
-            widget.populate()
-        elif scan_update == ScanUpdate.REMOVED:
-            for child in self._box.get_children():
-                if child.data == artist_id:
-                    child.destroy()
-                    break
+        for artist_id in item.new_album_artist_ids:
+            if scan_update == ScanUpdate.ADDED:
+                artist_name = App().artists.get_name(artist_id)
+                sortname = App().artists.get_sortname(artist_id)
+                self.add_value((artist_id, artist_name, sortname))
+            elif scan_update == ScanUpdate.REMOVED:
+                for child in self._box.get_children():
+                    if child.data == artist_id:
+                        child.destroy()
+                        break
 
 #######################
 # PRIVATE             #
@@ -217,7 +206,7 @@ class RoundedArtistsViewWithBanner(RoundedArtistsView):
             @param random as bool
         """
         album_ids = App().albums.get_ids([], [], self.storage_type,
-                                         True, OrderBy.ARTIST)
+                                         False, OrderBy.ARTIST)
         if not album_ids:
             return
         albums = [Album(album_id) for album_id in album_ids]
